diff graal/com.oracle.max.cri/src/com/oracle/max/cri/ci/CiFrame.java @ 5506:56860d3f9f39

More refactorings and renamings in preparation of ci/ri split.
author Thomas Wuerthinger <thomas.wuerthinger@oracle.com>
date Thu, 07 Jun 2012 18:12:01 +0200
parents 2fac5abf145f
children dc71b06d09f8
line wrap: on
line diff
--- a/graal/com.oracle.max.cri/src/com/oracle/max/cri/ci/CiFrame.java	Thu Jun 07 17:25:52 2012 +0200
+++ b/graal/com.oracle.max.cri/src/com/oracle/max/cri/ci/CiFrame.java	Thu Jun 07 18:12:01 2012 +0200
@@ -28,7 +28,7 @@
 
 /**
  * Represents the Java bytecode frame state(s) at a given position
  * including {@link CiValue locations} where to find the local variables,
  * operand stack values and locked objects of the bytecode frame(s).
  */
 public class CiFrame extends CiCodePos implements Serializable {
@@ -48,7 +48,7 @@
      * Note that the number of locals and the number of stack slots may be smaller than the
      * maximum number of locals and stack slots as specified in the compiled method.
      */
-    public final CiValue[] values;
+    public final RiValue[] values;
 
     /**
      * The number of locals in the values array.
@@ -87,7 +87,7 @@
      * @param numStack the depth of the stack
      * @param numLocks the number of locked objects
      */
-    public CiFrame(CiFrame caller, RiResolvedMethod method, int bci, boolean rethrowException, boolean duringCall, CiValue[] values, int numLocals, int numStack, int numLocks, long leafGraphId) {
+    public CiFrame(CiFrame caller, RiResolvedMethod method, int bci, boolean rethrowException, boolean duringCall, RiValue[] values, int numLocals, int numStack, int numLocks, long leafGraphId) {
         super(caller, method, bci);
         assert values != null;
         this.rethrowException = rethrowException;
@@ -105,7 +105,7 @@
      * @param i the local variable index
      * @return the value that can be used to reconstruct the local's current value
      */
-    public CiValue getLocalValue(int i) {
+    public RiValue getLocalValue(int i) {
         return values[i];
     }
 
@@ -114,7 +114,7 @@
      * @param i the stack index
      * @return the value that can be used to reconstruct the stack slot's current value
      */
-    public CiValue getStackValue(int i) {
+    public RiValue getStackValue(int i) {
         return values[i + numLocals];
     }
 
@@ -123,7 +123,7 @@
      * @param i the lock index
      * @return the value that can be used to reconstruct the lock's current value
      */
-    public CiValue getLockValue(int i) {
+    public RiValue getLockValue(int i) {
         return values[i + numLocals + numStack];
     }
@@ -28,7 +28,7 @@
 /**
  * Represents the Java bytecode frame state(s) at a given position
- * including {@link CiValue locations} where to find the local variables,
+ * including {@link RiValue locations} where to find the local variables,
  * operand stack values and locked objects of the bytecode frame(s).
  */